@@ -10,29 +10,20 @@ from billy.core import settings
 from billy.importers.names import get_legislator_id
 from billy.importers.utils import prepare_obj, update, insert_with_id
 
-import pymongo
-
 logger = logging.getLogger('billy')
 
 
-def ensure_indexes():
-    db.committees.ensure_index([('_all_ids', pymongo.ASCENDING)])
-    db.committees.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
-                                ('committee', pymongo.ASCENDING),
-                                ('subcommittee', pymongo.ASCENDING)])
-
-
 def import_committees_from_legislators(current_term, abbr):
     """ create committees from legislators that have committee roles """
 
     # for all current legislators
     for legislator in db.legislators.find({'roles': {'$elemMatch': {
-        'term': current_term, settings.LEVEL_FIELD: abbr}}}):
+            'term': current_term, settings.LEVEL_FIELD: abbr}}}):
 
         # for all committee roles
         for role in legislator['roles']:
             if (role['type'] == 'committee member' and
-                'committee_id' not in role):
+                    'committee_id' not in role):
 
                 spec = {settings.LEVEL_FIELD: abbr,
                         'chamber': role['chamber'],
@@ -47,7 +38,7 @@ def import_committees_from_legislators(current_term, abbr):
                     committee['_type'] = 'committee'
                     # copy LEVEL_FIELD from legislator to committee
                     committee[settings.LEVEL_FIELD] = \
-                            legislator[settings.LEVEL_FIELD]
+                        legislator[settings.LEVEL_FIELD]
                     committee['members'] = []
                     committee['sources'] = []
                     if 'subcommittee' not in committee:
@@ -118,8 +109,8 @@ def import_committee(data, current_session, current_term):
 
         for role in legislator['roles']:
             if (role['type'] == 'committee member' and
-                role['term'] == current_term and
-                role.get('committee_id') == committee['_id']):
+                    role['term'] == current_term and
+                    role.get('committee_id') == committee['_id']):
                 # if the position hadn't been copied over before, copy it now
                 if role.get('position') != member['role']:
                     role['position'] = member['role']
@@ -131,8 +122,7 @@ def import_committee(data, current_session, current_term):
                         'term': current_term,
                         'chamber': committee['chamber'],
                         'committee_id': committee['_id'],
-                        'position': member['role']
-                       }
+                        'position': member['role']}
             # copy over all necessary fields from committee
             new_role[settings.LEVEL_FIELD] = committee[settings.LEVEL_FIELD]
 
@@ -182,7 +172,6 @@ def import_committees(abbr, data_dir):
 
     link_parents(abbr)
 
-    ensure_indexes()
     return counts
 
 
@@ -194,7 +183,8 @@ def link_parents(abbr):
         else:
             parent = db.committees.find_one({settings.LEVEL_FIELD: abbr,
                                              'chamber': comm['chamber'],
-                                             'committee': comm['committee']})
+                                             'committee': comm['committee'],
+                                             'subcommittee': None})
             if not parent:
                 logger.warning("Failed finding parent for: %s" % sub)
                 comm['parent_id'] = None
