@@ -13,21 +13,10 @@ from billy.importers.names import get_legislator_id
 from billy.importers.utils import (prepare_obj, update, next_big_id,
                                    get_committee_id)
 
-import pymongo
-
 logger = logging.getLogger('billy')
 filters = settings.EVENT_FILTERS
 
 
-def ensure_indexes():
-    db.events.ensure_index([('when', pymongo.ASCENDING),
-                            (settings.LEVEL_FIELD, pymongo.ASCENDING),
-                            ('type', pymongo.ASCENDING)])
-    db.events.ensure_index([('when', pymongo.DESCENDING),
-                            (settings.LEVEL_FIELD, pymongo.ASCENDING),
-                            ('type', pymongo.ASCENDING)])
-
-
 def _insert_with_id(event):
     abbr = event[settings.LEVEL_FIELD]
     id = next_big_id(abbr, 'E', 'event_ids')
@@ -76,10 +65,8 @@ def import_events(abbr, data_dir, import_actions=False):
             entity['id'] = id
 
         for bill in data['related_bills']:
-            bill['_scraped_bill_id'] = bill['bill_id']
             bill_id = bill['bill_id']
             bill_id = fix_bill_id(bill_id)
-            bill['bill_id'] = ""
             db_bill = db.bills.find_one({
                 "$or": [
                     {
@@ -103,9 +90,9 @@ def import_events(abbr, data_dir, import_actions=False):
             # Events are really hard to pin to a chamber. Some of these are
             # also a committee considering a bill from the other chamber, or
             # something like that.
-            bill['bill_id'] = db_bill['_id']
+            bill['id'] = db_bill['_id']
+            bill['bill_id'] = bill_id
         import_event(data)
-    ensure_indexes()
 
 
 def normalize_dates(event):
@@ -115,12 +102,16 @@ def normalize_dates(event):
     tz = pytz.timezone(meta['capitol_timezone'])
 
     # right now, we just need to update when the event is.
-    for attr in ['when']:
-        if not event[attr].tzinfo:
-            localtime = tz.localize(event[attr])
+    attr = "when"
+    if not event[attr].tzinfo:
+        localtime = tz.localize(event[attr])
+
+    tzdb_name = localtime.tzinfo.zone
+
+    utctime = datetime.datetime(*localtime.utctimetuple()[:6])
+    event[attr] = utctime
+    event["timezone"] = tzdb_name
 
-        utctime = datetime.datetime(*localtime.utctimetuple()[:6])
-        event[attr] = utctime
     return event
 
 
