@@ -10,31 +10,10 @@ from billy.core import settings
 from billy.importers.utils import insert_with_id, update, prepare_obj
 from billy.importers.filters import apply_filters
 
-import pymongo
-
 filters = settings.LEGISLATOR_FILTERS
 logger = logging.getLogger('billy')
 
 
-def ensure_indexes():
-    db.legislators.ensure_index('_all_ids', pymongo.ASCENDING)
-    db.legislators.ensure_index([('roles.{0}'.format(settings.LEVEL_FIELD),
-                                  pymongo.ASCENDING),
-                                 ('roles.type', pymongo.ASCENDING),
-                                 ('roles.term', pymongo.ASCENDING),
-                                 ('roles.chamber', pymongo.ASCENDING),
-                                 ('_scraped_name', pymongo.ASCENDING),
-                                 ('first_name', pymongo.ASCENDING),
-                                 ('last_name', pymongo.ASCENDING),
-                                 ('middle_name', pymongo.ASCENDING),
-                                 ('suffixes', pymongo.ASCENDING)],
-                                name='role_and_name_parts')
-    db.legislators.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
-                                 ('active', pymongo.ASCENDING),
-                                 ('chamber', pymongo.ASCENDING),
-                                ])
-
-
 def import_legislators(abbr, data_dir):
     data_dir = os.path.join(data_dir, abbr)
     pattern = os.path.join(data_dir, 'legislators', '*.json')
@@ -60,8 +39,6 @@ def import_legislators(abbr, data_dir):
     activate_legislators(current_term, abbr)
     deactivate_legislators(current_term, abbr)
 
-    ensure_indexes()
-
     return counts
 
 
@@ -70,16 +47,16 @@ def activate_legislators(current_term, abbr):
     Sets the 'active' flag on legislators and populates top-level
     district/chamber/party fields for currently serving legislators.
     """
-    for legislator in db.legislators.find({'roles': {'$elemMatch':
-             {settings.LEVEL_FIELD: abbr, 'type': 'member',
-              'term': current_term}}}):
+    for legislator in db.legislators.find(
+        {'roles': {'$elemMatch':
+                   {settings.LEVEL_FIELD: abbr, 'term': current_term}}}):
         active_role = legislator['roles'][0]
 
-        if not active_role['end_date']:
+        if not active_role.get('end_date') and active_role['type'] == 'member':
             legislator['active'] = True
-            legislator['party'] = active_role['party']
-            legislator['district'] = active_role['district']
-            legislator['chamber'] = active_role['chamber']
+            legislator['party'] = active_role.get('party', None)
+            legislator['district'] = active_role.get('district', None)
+            legislator['chamber'] = active_role.get('chamber', None)
 
         legislator['updated_at'] = datetime.datetime.utcnow()
         db.legislators.save(legislator, safe=True)
@@ -89,21 +66,16 @@ def deactivate_legislators(current_term, abbr):
 
     # legislators without a current term role or with an end_date
     for leg in db.legislators.find(
-        {'$or': [
-            {'roles': {'$elemMatch':
-                       {'term': {'$ne': current_term},
-                        'type': 'member',
-                          settings.LEVEL_FIELD: abbr,
-                       }},
-            },
-            {'roles': {'$elemMatch':
-                       {'term': current_term,
-                        'type': 'member',
-                          settings.LEVEL_FIELD: abbr,
-                        'end_date': {'$ne':None}}},
-            },
-
-        ]}):
+            {'$or': [
+                {'roles': {'$elemMatch': {
+                    'term': {'$ne': current_term},
+                    'type': 'member', settings.LEVEL_FIELD: abbr}}},
+                {'roles': {'$elemMatch': {
+                    'term': current_term,
+                    'type': 'member',
+                    settings.LEVEL_FIELD: abbr,
+                    'end_date': {'$ne': None}}}}
+            ]}):
 
         if 'old_roles' not in leg:
             leg['old_roles'] = {}
