@@ -1,8 +1,7 @@
 from collections import defaultdict
 
-from billy import db
-from billy.conf import settings
-from billy.utils import metadata
+from billy.core import db
+from billy.core import settings
 
 
 class SubjectCategorizer(object):
@@ -21,15 +20,9 @@ class SubjectCategorizer(object):
             subjects.update(categories)
         bill['subjects'] = list(subjects)
 
-    def categorize_bills(self, latest_term_only=False):
-        meta = metadata(self.abbr)
+    def categorize_bills(self):
         spec = {settings.LEVEL_FIELD: self.abbr}
 
-        # process just the sessions from the latest term
-        if latest_term_only:
-            sessions = meta['terms'][-1]['sessions']
-            spec['session'] = {'$in': sessions}
-
         for bill in db.bills.find(spec):
             self.categorize_bill(bill)
             db.bills.save(bill, safe=True)
