@@ -20,12 +20,14 @@ def _get_property_dict(schema):
         pdict[k] = {}
         if 'items' in v and 'properties' in v['items']:
             pdict[k] = _get_property_dict(v['items'])
+    pdict[settings.LEVEL_FIELD] = {}
     return pdict
 
 
 # load standard fields from schema files
 standard_fields = {}
-for _type in ('bill', 'person', 'committee', 'metadata', 'vote', 'event'):
+for _type in ('bill', 'person', 'committee', 'metadata', 'vote',
+              'event', 'speech'):
     fname = os.path.join(os.path.split(__file__)[0],
                          '../schemas/%s.json' % _type)
     schema = json.load(open(fname))
@@ -66,7 +68,7 @@ def insert_with_id(obj):
     cursor = collection.find({'_id': id_reg}).sort('_id', -1).limit(1)
 
     try:
-        new_id = int(cursor.next()['_id'][3:]) + 1
+        new_id = int(cursor.next()['_id'][len(abbr) + 1:]) + 1
     except StopIteration:
         new_id = 1
 
@@ -171,6 +173,8 @@ def update(old, new, collection, sneaky_update_filter=None):
         old['updated_at'] = datetime.datetime.utcnow()
         collection.save(old, safe=True)
 
+    return need_save
+
 
 def convert_timestamps(obj):
     """
@@ -185,19 +189,10 @@ def convert_timestamps(obj):
             except TypeError:
                 raise TypeError("expected float for %s, got %s" % (key, value))
 
-    for key in ('sources', 'actions', 'votes'):
+    for key in ('sources', 'actions', 'votes', 'roles'):
         for child in obj.get(key, []):
             convert_timestamps(child)
 
-    for term in obj.get('terms', []):
-        convert_timestamps(term)
-
-    for details in obj.get('session_details', {}).values():
-        convert_timestamps(details)
-
-    for role in obj.get('roles', []):
-        convert_timestamps(role)
-
     return obj
 
 
@@ -319,7 +314,7 @@ def merge_legislators(leg1, leg2):
         #      old_roles & roles!! There's a potenital for data loss, but it's
         #      not that big of a thing.
         #   -- paultag & jamesturk, 02-02-2012
-        if len(leg1[roles]) > 0:
+        if len(leg1[roles]) > 0 and leg2[roles][0] != leg1[roles][0]:
             crole = leg1[roles][0]
             try:
                 leg1[old_roles][crole['term']].append(crole)
