@@ -117,7 +117,9 @@ class Document(dict):
         chamber = self['chamber']
         if chamber == 'joint':
             return 'Joint'
-        return self.metadata['%s_chamber_name' % self['chamber']]
+        elif chamber is None:
+            return ''
+        return self.metadata['chambers'][chamber]['name']
 
     @property
     def collection_name(self):
@@ -289,7 +291,7 @@ class RelatedDocuments(object):
     subclass, and when accessed on an instance, it will return
     a cursor of all objects that reference this instance's id using
     the key `model_key`. For example, this could be used to get all
-    "legislator" documents for a given state's metadata.
+    "legislator" documents for a given "metadata".
     '''
     def __init__(self, model, model_keys, instance_key='_id',
                  sort=None, model_keys_operator='$or',
@@ -305,7 +307,7 @@ class RelatedDocuments(object):
         :param model_keys_operator: if multiple model_keys are given, the
             boolean mongo query to relate them, like $and, $or, etc.
         :param default_spec_instance_keys: extra instance keys used to populate
-            the default mongo query spec with, like 'state' and 'session'.
+            the default mongo query spec with, like 'abbr' or 'session'.
             Useful in constraining potentially brutal queries.
         '''
         self.model = model
@@ -367,7 +369,7 @@ class CursorWrapper(object):
     In English, this enables:
 
     for vote in legislator.votes_manager():
-        print vote.legislator
+        print(vote.legislator)
 
     This was the only way I could think of to do this without
     a huge rewrite. The solution in the AttrManager classes is
