@@ -3,7 +3,8 @@ import urlparse
 import datetime
 from django.template.defaultfilters import truncatewords
 
-from .base import db, feeds_db, Document
+from billy.core import mdb as db, feeds_db, settings
+from .base import Document
 from .metadata import Metadata
 
 
@@ -142,4 +143,4 @@ class FeedEntry(Document):
 
     @property
     def metadata(self):
-        return Metadata.get_object(self['state'])
+        return Metadata.get_object(self[settings.LEVEL_FIELD])
