@@ -1,7 +1,7 @@
 from collections import defaultdict
 
-from billy import db
-from billy.conf import settings
+from billy.core import db
+from billy.core import settings
 from billy.reports.utils import update_common
 
 
