@@ -22,7 +22,7 @@ class ScrapeError(Exception):
     def __str__(self):
         if self.orig_exception:
             return '%s\nOriginal Exception: %s' % (self.msg,
-                                        self.orig_exception)
+                                                   self.orig_exception)
         else:
             return self.msg
 
@@ -38,25 +38,6 @@ class NoDataForPeriod(ScrapeError):
         return 'No data exists for %s' % self.period
 
 
-# maps scraper_type -> scraper
-_scraper_registry = dict()
-
-
-class ScraperMeta(type):
-    """ register derived scrapers in a central registry """
-
-    def __new__(meta, classname, bases, classdict):
-        cls = type.__new__(meta, classname, bases, classdict)
-
-        abbr = getattr(cls, settings.LEVEL_FIELD, None)
-        scraper_type = getattr(cls, 'scraper_type', None)
-
-        if abbr and scraper_type:
-            _scraper_registry[scraper_type] = cls
-
-        return cls
-
-
 class Scraper(scrapelib.Scraper):
     """ Base class for all Scrapers
 
@@ -64,12 +45,10 @@ class Scraper(scrapelib.Scraper):
     arguments against metadata.
     """
 
-    __metaclass__ = ScraperMeta
-
     latest_only = False
 
     def __init__(self, metadata, output_dir=None, strict_validation=None,
-                 fastmode=False, **kwargs):
+                 fastmode=False):
         """
         Create a new Scraper instance.
 
@@ -77,19 +56,18 @@ class Scraper(scrapelib.Scraper):
         :param output_dir: the data directory to use
         :param strict_validation: exit immediately if validation fails
         """
+        super(Scraper, self).__init__()
 
-        # configure underlying scrapelib object
-        kwargs['cache_obj'] = scrapelib.FileCache(settings.BILLY_CACHE_DIR)
-        kwargs['requests_per_minute'] = settings.SCRAPELIB_RPM
-        kwargs['timeout'] = settings.SCRAPELIB_TIMEOUT
-        kwargs['retry_attempts'] = settings.SCRAPELIB_RETRY_ATTEMPTS
-        kwargs['retry_wait_seconds'] = settings.SCRAPELIB_RETRY_WAIT_SECONDS
+        # scrapelib overrides
+        self.timeout = settings.SCRAPELIB_TIMEOUT
+        self.cache_storage = scrapelib.FileCache(settings.BILLY_CACHE_DIR)
+        self.requests_per_minute = settings.SCRAPELIB_RPM
+        self.retry_attempts = settings.SCRAPELIB_RETRY_ATTEMPTS
+        self.retry_wait_seconds = settings.SCRAPELIB_RETRY_WAIT_SECONDS
 
         if fastmode:
-            kwargs['requests_per_minute'] = 0
-            kwargs['cache_write_only'] = False
-
-        super(Scraper, self).__init__(**kwargs)
+            self.requests_per_minute = 0
+            self.cache_write_only = False
 
         self.metadata = metadata
         self.output_dir = output_dir
@@ -101,6 +79,8 @@ class Scraper(scrapelib.Scraper):
         # validation
         self.strict_validation = strict_validation
         self.validator = DatetimeValidator()
+        self._schema = {}
+        self._load_schemas()
 
         self.follow_robots = False
 
@@ -113,16 +93,38 @@ class Scraper(scrapelib.Scraper):
         self.error = self.logger.error
         self.critical = self.logger.critical
 
+    def _load_schemas(self):
+        """ load all schemas into schema dict """
+
+        types = ('bill', 'committee', 'person', 'vote', 'event', 'speech')
+
+        for type in types:
+            schema_path = os.path.join(os.path.split(__file__)[0],
+                                       '../schemas/%s.json' % type)
+            self._schema[type] = json.load(open(schema_path))
+            self._schema[type]['properties'][settings.LEVEL_FIELD] = {
+                'minLength': 2, 'type': 'string'}
+
+        # bills & votes
+        self._schema['bill']['properties']['session']['enum'] = \
+            self.all_sessions()
+        self._schema['vote']['properties']['session']['enum'] = \
+            self.all_sessions()
+
+        # legislators
+        terms = [t['name'] for t in self.metadata['terms']]
+        # ugly break here b/c this line is nearly impossible to split
+        self._schema['person']['properties']['roles'][
+            'items']['properties']['term']['enum'] = terms
+
     @property
     def object_count(self):
         # number of distinct output filenames
         return len(self.output_names)
 
     def validate_json(self, obj):
-        if not hasattr(self, '_schema'):
-            self._schema = self._get_schema()
         try:
-            self.validator.validate(obj, self._schema)
+            self.validator.validate(obj, self._schema[obj['_type']])
         except ValueError as ve:
             self.warning(str(ve))
             if self.strict_validation:
@@ -172,12 +174,23 @@ class Scraper(scrapelib.Scraper):
         raise NoDataForPeriod(term)
 
     def save_object(self, obj):
-        # copy over LEVEL_FIELD
-        obj[settings.LEVEL_FIELD] = getattr(self, settings.LEVEL_FIELD)
+        self.log('save %s %s', obj['_type'], unicode(obj))
+
+        # copy jurisdiction to LEVEL_FIELD
+        obj[settings.LEVEL_FIELD] = getattr(self, 'jurisdiction')
 
         filename = obj.get_filename()
         self.output_names.add(filename)     # keep tally of all output names
-        with open(os.path.join(self.output_dir, self.scraper_type, filename),
+
+        # pluralize type
+        if obj['_type'] == 'speech':
+            data_dir = 'speeches'
+        elif obj['_type'] == 'person':
+            data_dir = 'legislators'
+        else:
+            data_dir = obj['_type'] + 's'
+
+        with open(os.path.join(self.output_dir, data_dir, filename),
                   'w') as f:
             json.dump(obj, f, cls=JSONEncoderPlus)
 
@@ -218,23 +231,32 @@ def get_scraper(mod_path, scraper_type):
 
     # act of importing puts it into the registry
     try:
-        mod_path = '%s.%s' % (mod_path, scraper_type)
-        importlib.import_module(mod_path)
+        module = importlib.import_module(mod_path)
     except ImportError as e:
         raise ScrapeError("could not import %s" % mod_path, e)
 
-    # now pull the class out of the registry
-    try:
-        ScraperClass = _scraper_registry[scraper_type]
-    except KeyError as e:
-        raise ScrapeError("no %s scraper found in module %s" %
-                           (scraper_type, mod_path))
+    # now find the class within the module
+    ScraperClass = None
+
+    for k, v in module.__dict__.iteritems():
+        if k.startswith('_'):
+            continue
+        if getattr(v, 'scraper_type', None) == scraper_type:
+            if ScraperClass:
+                raise ScrapeError("two %s scrapers found in module %s: %s %s" %
+                                  (scraper_type, mod_path, ScraperClass, k))
+            ScraperClass = v
+
+    if not ScraperClass:
+        raise ScrapeError("no %s scraper found in module %s" % (
+            scraper_type, mod_path))
+
     return ScraperClass
 
 
 def check_sessions(metadata, sessions):
     all_sessions_in_terms = list(reduce(lambda x, y: x + y,
-                                   [x['sessions'] for x in metadata['terms']]))
+                                 [x['sessions'] for x in metadata['terms']]))
     # copy the list to avoid modifying it
     metadata_session_details = list(metadata.get('_ignored_scraped_sessions',
                                                  []))
