@@ -1,5 +1,3 @@
-import os
-import json
 import logging
 
 from billy.scrape import Scraper, SourcedObject
@@ -11,13 +9,6 @@ class BillScraper(Scraper):
 
     scraper_type = 'bills'
 
-    def _get_schema(self):
-        schema_path = os.path.join(os.path.split(__file__)[0],
-                                   '../schemas/bill.json')
-        schema = json.load(open(schema_path))
-        schema['properties']['session']['enum'] = self.all_sessions()
-        return schema
-
     def scrape(self, chamber, session):
         """
         Grab all the bills for a given chamber and session. Must be
@@ -28,16 +19,7 @@ class BillScraper(Scraper):
         """
         raise NotImplementedError('BillScrapers must define a scrape method')
 
-    def save_bill(self, bill):
-        """
-        Save a scraped :class:`~billy.scrape.bills.Bill` object.
-
-        Should be called after all data for the given bill has been collected.
-        """
-        self.log("save_bill %s %s: %s" % (bill['chamber'],
-                                          bill['session'],
-                                          bill['bill_id']))
-        self.save_object(bill)
+    save_bill = Scraper.save_object
 
 
 class Bill(SourcedObject):
@@ -148,11 +130,8 @@ class Bill(SourcedObject):
         d = dict(name=name, url=url, mimetype=mimetype, **kwargs)
         self['versions'].append(d)
 
-    def add_action(self, actor, action, date,
-                    type=None,
-                    committees=None,
-                    legislators=None,
-                   **kwargs):
+    def add_action(self, actor, action, date, type=None, committees=None,
+                   legislators=None, **kwargs):
         """
         Add an action that was performed on this bill.
 
@@ -235,3 +214,7 @@ class Bill(SourcedObject):
         filename = "%s_%s_%s.json" % (self['session'], self['chamber'],
                                       self['bill_id'])
         return filename.encode('ascii', 'replace')
+
+    def __unicode__(self):
+        return "%s %s: %s" % (self['chamber'], self['session'],
+                              self['bill_id'])
