@@ -1,6 +1,3 @@
-import os
-import json
-
 from billy.scrape import Scraper, SourcedObject
 
 
@@ -8,25 +5,11 @@ class CommitteeScraper(Scraper):
 
     scraper_type = 'committees'
 
-    def _get_schema(self):
-        schema_path = os.path.join(os.path.split(__file__)[0],
-                                   '../schemas/committee.json')
-        schema = json.load(open(schema_path))
-        return schema
-
     def scrape(self, chamber, term):
         raise NotImplementedError('CommitteeScrapers must define a '
                                   'scrape method')
 
-    def save_committee(self, committee):
-        """
-        Save a scraped :class:`~billy.scrape.committees.Committee` object.
-        """
-        name = committee['committee']
-        if committee.get('subcommittee', None):
-            name += '_%s' % committee['subcommittee']
-        self.log("save_committee: %s" % name)
-        self.save_object(committee)
+    save_committee = Scraper.save_object
 
 
 class Committee(SourcedObject):
@@ -63,3 +46,10 @@ class Committee(SourcedObject):
             name += '_%s' % self['subcommittee']
 
         return "%s_%s.json" % (self['chamber'], name.replace('/', ','))
+
+    def __unicode__(self):
+        name = self['committee']
+        sub = self.get('subcommittee', None)
+        if sub:
+            name += ': %s' % sub
+        return name
