@@ -1,6 +1,4 @@
-import os
 import uuid
-import json
 
 from billy.scrape import Scraper, SourcedObject
 
@@ -9,29 +7,18 @@ class EventScraper(Scraper):
 
     scraper_type = 'events'
 
-    def _get_schema(self):
-        schema_path = os.path.join(os.path.split(__file__)[0],
-                                   '../schemas/event.json')
-
-        with open(schema_path) as f:
-            schema = json.load(f)
-
-        return schema
-
     def scrape(self, chamber, session):
         raise NotImplementedError("EventScrapers must define a scrape method")
 
-    def save_event(self, event):
-        self.log("save_event %s %s: %s" % (event['when'],
-                                           event['type'],
-                                           event['description']))
-        self.save_object(event)
+    save_event = Scraper.save_object
 
 
 class Event(SourcedObject):
     def __init__(self, session, when, type,
                  description, location, end=None, **kwargs):
         super(Event, self).__init__('event', **kwargs)
+        self.uuid = uuid.uuid1()  # If we need to save an event more than once
+
         self['session'] = session
         self['when'] = when
         self['type'] = type
@@ -69,4 +56,7 @@ class Event(SourcedObject):
         self['participants'].append(kwargs)
 
     def get_filename(self):
-        return "%s.json" % str(uuid.uuid1())
+        return "%s.json" % str(self.uuid)
+
+    def __unicode__(self):
+        return "%s %s: %s" % (self['when'], self['type'], self['description'])
