@@ -1,7 +1,8 @@
 from billy.core import settings, _configure_db
 settings.MONGO_DATABASE += '_test'
+settings.MONGO_USER_DATABASE += '_test'
 _configure_db(settings.MONGO_HOST, settings.MONGO_PORT,
-              settings.MONGO_DATABASE)
+              settings.MONGO_DATABASE, settings.MONGO_USER_DATABASE)
 import pymongo
 
 
