@@ -1,3 +1,4 @@
+from __future__ import print_function
 from billy.importers.utils import merge_legislators
 
 import json
@@ -6,7 +7,7 @@ import os
 
 def _load_test_data(test_name):
     test_data = os.path.join(os.path.dirname(os.path.dirname(__file__)),
-        "leg_merge_test_data")
+                             "leg_merge_test_data")
     folder = "%s/%s/" % (test_data, test_name)
     leg1 = json.loads(open(folder + "1.json", 'r').read())
     leg2 = json.loads(open(folder + "2.json", 'r').read())
@@ -17,10 +18,7 @@ def _load_test_data(test_name):
 
 def _check_results(one, two):
     if one != two:
-        print ""
-        print one
-        print two
-        print ""
+        print('\n', one, '\n', two, '\n', sep='')
     return one == two
 
 
