@@ -42,16 +42,16 @@ def setup_func():
         u'yes_count': 47,
         u'yes_votes': [
             {u'leg_id': u'CAL000104', u'name': u'Ammiano'},
-            ]
-        }
+        ]
+    }
 
     # Add a vote for the current session bill.
     db.votes.insert(dict(vote, bill_id='CAB00007468',
-                               date=datetime.datetime(2011, 12, 6, 0, 0)))
+                         date=datetime.datetime(2011, 12, 6, 0, 0)))
 
     # Add a vote for the prior session bill.
     db.votes.insert(dict(vote, bill_id='CAB00005131',
-                               date=datetime.datetime(2009, 12, 6, 0, 0)))
+                         date=datetime.datetime(2009, 12, 6, 0, 0)))
 
     # Insert some test records.
     db.legislators.insert({
@@ -141,16 +141,13 @@ def setup_func():
             }
         ],
         "state": "ca",
-        })
+    })
 
     db.metadata.insert({
         u'_id': u'ca',
         u'_type': u'metadata',
         u'abbreviation': u'ca',
         u'legislature_name': u'California State Legislature',
-        u'lower_chamber_name': u'Assembly',
-        u'lower_chamber_term': 2,
-        u'lower_chamber_title': u'Assemblymember',
         u'name': u'California',
         u'session_details': {
             u'20092010': {
@@ -197,45 +194,41 @@ def setup_func():
                 u'display_name': u'2011-2012, 1st Special Session',
                 u'type': u'special'}},
 
-        u'terms': [{
-            u'+start_date': datetime.datetime(2008, 12, 1, 0, 0),
-            u'end_year': 2010,
-            u'name': u'20092010',
-            u'sessions': [
-                u'20092010',
-                u'20092010 Special Session 1',
-                u'20092010 Special Session 2',
-                u'20092010 Special Session 3',
-                u'20092010 Special Session 4',
-                u'20092010 Special Session 5',
-                u'20092010 Special Session 6',
-                u'20092010 Special Session 7',
-                u'20092010 Special Session 8'],
-           u'start_year': 2009},
-
-          {u'+start_date': datetime.datetime(2010, 12, 6, 0, 0),
-           u'end_year': 2012,
-           u'name': u'20112012',
-           u'sessions': [u'20112012 Special Session 1', u'20112012'],
-           u'start_year': 2011},
-
-          {u'+start_date': datetime.datetime(2010, 12, 6, 0, 0),
-           u'end_year': 2012,
-           u'name': u'fake-term',
-           u'sessions': [u'fake-session'],
-           u'start_year': 2011},
-
-          {u'+start_date': datetime.datetime(2010, 12, 6, 0, 0),
-           u'end_year': 2012,
-           u'name': u'fake-term2',
-           u'sessions': [u'fake-session2'],
-           u'start_year': 2011},
-
-        ],
-         u'upper_chamber_name': u'Senate',
-         u'upper_chamber_term': 4,
-         u'upper_chamber_title': u'Senator'})
-    print db.name, db.metadata.count()
+        u'terms': [
+            {
+                u'+start_date': datetime.datetime(2008, 12, 1, 0, 0),
+                u'end_year': 2010,
+                u'name': u'20092010',
+                u'sessions': [u'20092010', u'20092010 Special Session 1',
+                              u'20092010 Special Session 2', u'20092010 Special Session 3',
+                              u'20092010 Special Session 4', u'20092010 Special Session 5',
+                              u'20092010 Special Session 6', u'20092010 Special Session 7',
+                              u'20092010 Special Session 8'],
+                u'start_year': 2009
+            },
+            {
+                u'+start_date': datetime.datetime(2010, 12, 6, 0, 0),
+                u'end_year': 2012,
+                u'name': u'20112012',
+                u'sessions': [u'20112012 Special Session 1', u'20112012'],
+                u'start_year': 2011
+            },
+            {
+                u'+start_date': datetime.datetime(2010, 12, 6, 0, 0),
+                u'end_year': 2012,
+                u'name': u'fake-term',
+                u'sessions': [u'fake-session'],
+                u'start_year': 2011
+            },
+            {
+                u'+start_date': datetime.datetime(2010, 12, 6, 0, 0),
+                u'end_year': 2012,
+                u'name': u'fake-term2',
+                u'sessions': [u'fake-session2'],
+                u'start_year': 2011
+            },
+        ]
+    })
 
     # A current session bill, where current session is 20112012.
     db.bills.insert({
@@ -249,7 +242,7 @@ def setup_func():
             u'passed_lower': datetime.datetime(2011, 6, 2, 0, 0),
             u'passed_upper': None,
             u'signed': None},
-        u'alternate_titles': [u'An act to amend Sections 226, 3351, 3352, 3551, 3708, 3715, 6303, and 6314 of, to repeal Section 4156 of, and to add Part 4.5 (commencing with Section 1450) to Division 2 of, the Labor Code, relating to domestic work employees.'],
+        u'alternate_titles': [],
         u'bill_id': u'AB 889',
         u'chamber': u'lower',
         u'country': u'us',
@@ -257,15 +250,15 @@ def setup_func():
         u'documents': [],
         u'level': u'state',
         u'session': u'20112012',
-        u'sources': [{u'url': u'http://leginfo.legislature.ca.gov/faces/billNavClient.xhtml?bill_id=201120120AB889'}],
+        u'sources': [{u'url': u'http://leginfo.legislature.ca.gov/fake'}],
         u'sponsors': [
             {u'leg_id': u'CAL000104',
              u'name': u'Ammiano',
              u'official_type': u'LEAD_AUTHOR',
              u'type': u'primary'},
-             ],
+        ],
         u'state': u'ca',
-        })
+    })
 
     # A prior session bill, where prior is 20092010.
     db.bills.insert({
@@ -283,10 +276,11 @@ def setup_func():
         u'country': u'us',
         u'session': u'20092010 Special Session 4',
         u'sponsors': [
-            {u'leg_id': u'CAL000104', u'name': u'Ammiano', u'type': u'cosponsor'},
-            ],
+            {u'leg_id': u'CAL000104', u'name': u'Ammiano',
+             u'type': u'cosponsor'}
+        ],
         u'state': u'ca',
-        })
+    })
 
 
 '''
