@@ -1,11 +1,14 @@
-import datetime
+import os
 import json
 import re
 import time
 import urllib
+import datetime
 import urlparse
+import contextlib
 
 from bson import ObjectId
+from django.core.exceptions import ImproperlyConfigured
 
 from billy.core import db
 import difflib
@@ -33,7 +36,7 @@ def chamber_name(abbr, chamber):
     if chamber in ('joint', 'other'):
         return 'Joint'
 
-    return metadata(abbr)['%s_chamber_name' % chamber].split()[0]
+    return metadata(abbr)['chambers'][chamber]['name'].split()[0]
 
 
 def parse_param_dt(dt):
@@ -109,10 +112,14 @@ def textual_diff(l1, l2):
 
 # fixing bill ids
 _bill_id_re = re.compile(r'([A-Z]*)\s*0*([-\d]+)')
+_mi_bill_id_re = re.compile(r'(SJR|HJR)\s*([A-Z]+)')
 
 
 def fix_bill_id(bill_id):
     bill_id = bill_id.replace('.', '')
+    # special case for MI Joint Resolutions
+    if _mi_bill_id_re.match(bill_id):
+        return _mi_bill_id_re.sub(r'\1 \2', bill_id, 1).strip()
     return _bill_id_re.sub(r'\1 \2', bill_id, 1).strip()
 
 
@@ -123,3 +130,51 @@ def find_bill(query, fields=None):
         query['alternate_bill_ids'] = bill_id
         bill = db.bills.find_one(query, fields=fields)
     return bill
+
+try:
+    from django.contrib.sites.models import Site
+
+    def get_domain():
+        return Site.objects.get_current().domain
+except (ImportError, ImproperlyConfigured):
+    def get_domain():           # noqa
+        return 'example.com'
+
+
+@contextlib.contextmanager
+def cd(path):
+    '''Creates the path if it doesn't exist'''
+    old_dir = os.getcwd()
+    try:
+        os.makedirs(path)
+    except OSError:
+        pass
+    os.chdir(path)
+    try:
+        yield
+    finally:
+        os.chdir(old_dir)
+
+
+class CachedAttr(object):
+    '''Computes attribute value and caches it in instance.
+
+    Example:
+        class MyClass(object):
+            def myMethod(self):
+                # ...
+            myMethod = CachedAttribute(myMethod)
+    Use "del inst.myMethod" to clear cache.
+
+    Source: http://code.activestate.com/recipes/276643-caching-and-aliasing-with-descriptors/'''
+
+    def __init__(self, method, name=None):
+        self.method = method
+        self.name = name or method.__name__
+
+    def __get__(self, inst, cls):
+        if inst is None:
+            return self
+        result = self.method(inst)
+        setattr(inst, self.name, result)
+        return result
