@@ -4,6 +4,7 @@ import datetime as dt
 from pprint import pformat
 
 from django import template
+from billy.core import settings
 
 register = template.Library()
 
@@ -28,6 +29,11 @@ def key(d, key_name):
         return None
 
 
+@register.filter
+def level(d):
+    return d[settings.LEVEL_FIELD]
+
+
 @register.filter
 def minus(d1, d2):
     return d1 - d2
