@@ -7,7 +7,7 @@ from collections import defaultdict
 
 from django.http import HttpResponse
 
-from billy.core import db
+from billy.core import db, feeds_db
 from billy.models import Bill
 from billy.core import settings
 from billy.utils import find_bill, parse_param_dt
@@ -18,38 +18,21 @@ from piston.utils import rc
 from piston.handler import BaseHandler, HandlerMetaClass
 
 
-_chamber_aliases = {
-    'assembly': 'lower',
-    'house': 'lower',
-    'senate': 'upper',
-}
-
-
-_lower_fields = (settings.LEVEL_FIELD,)
+_lower_fields = (settings.LEVEL_FIELD, 'chamber')
 
 
 def _build_mongo_filter(request, keys, icase=True):
     _filter = {}
     keys = set(keys) - set(['fields'])
 
-    try:
-        keys.remove('subjects')
-        if 'subject' in request.GET:
-            _filter['subjects'] = {'$all': request.GET.getlist('subject')}
-    except KeyError:
-        pass
-
     for key in keys:
         value = request.GET.get(key)
         if value:
-            if key == 'chamber':
-                value = value.lower()
-                _filter[key] = _chamber_aliases.get(value, value)
-            elif key in _lower_fields:
+            if key in _lower_fields:
                 _filter[key] = value.lower()
             elif key.endswith('__in'):
                 values = value.split('|')
-                _filter[key[:-4]] = {'$in': values}
+                _filter[key[:-4]] = values
             else:
                 # We use regex queries to get case insensitive search - this
                 # means they won't use any indexes for now. Real case
@@ -120,24 +103,50 @@ class BillyHandler(BaseHandler):
     allowed_methods = ('GET',)
 
 
+def _metadata_backwards_shim(metadata):
+    if 'chambers' in metadata:
+        for chamber_type, chamber in metadata['chambers'].iteritems():
+            for field in ('name', 'title', 'term'):
+                if field in chamber:
+                    metadata[chamber_type + '_chamber_' + field] = \
+                        chamber[field]
+    return metadata
+
+
 class AllMetadataHandler(BillyHandler):
     def read(self, request):
+        use_shim = bool(request.GET.get('fields'))
         fields = _build_field_list(request, {'abbreviation': 1,
                                              'name': 1,
                                              'feature_flags': 1,
+                                             'chambers': 1,
                                              '_id': 0
                                             })
+        for f in fields.copy():
+            if '_chamber_' in f:
+                use_shim = True
+                fields['chambers'] = 1
         data = db.metadata.find(fields=fields).sort('name')
-        return list(data)
+        if use_shim:
+            return [_metadata_backwards_shim(m) for m in data]
+        else:
+            return list(data)
 
 
 class MetadataHandler(BillyHandler):
     def read(self, request, abbr):
-        """
-        Get metadata about a legislature.
-        """
-        return db.metadata.find_one({'_id': abbr.lower()},
-                                    fields=_build_field_list(request))
+        use_shim = bool(request.GET.get('fields'))
+        field_list = _build_field_list(request)
+        if field_list:
+            for f in field_list.copy():
+                if '_chamber_' in f:
+                    use_shim = True
+                    field_list['chambers'] = 1
+        data = db.metadata.find_one({'_id': abbr.lower()}, fields=field_list)
+        if use_shim:
+            return _metadata_backwards_shim(data)
+        else:
+            return data
 
 
 class BillHandler(BillyHandler):
@@ -151,20 +160,20 @@ class BillHandler(BillyHandler):
                      'bill_id': bill_id}
             if chamber:
                 query['chamber'] = chamber.lower()
+
         fields = _build_field_list(request)
         bill = find_bill(query, fields=fields)
         vote_fields = _get_vote_fields(fields)
         # include votes if no fields are specified, if it is specified, or
         # if subfields are specified
-        if not fields or 'votes' in fields or vote_fields:
+        if bill and (not fields or 'votes' in fields or vote_fields):
             bill['votes'] = list(db.votes.find({'bill_id': bill['_id']},
-                                          fields=vote_fields))
+                                               fields=vote_fields))
         return bill
 
 
 class BillSearchHandler(BillyHandler):
     def read(self, request):
-
         bill_fields = {'title': 1, 'created_at': 1, 'updated_at': 1,
                        'bill_id': 1, 'type': 1, settings.LEVEL_FIELD: 1,
                        'session': 1, 'chamber': 1, 'subjects': 1, '_type': 1,
@@ -173,21 +182,36 @@ class BillSearchHandler(BillyHandler):
         bill_fields = _build_field_list(request, bill_fields)
 
         # normal mongo search logic
-        base_fields = _build_mongo_filter(request, (settings.LEVEL_FIELD,
-                                                    'chamber', 'subjects',
-                                                    'bill_id', 'bill_id__in'))
+        base_fields = _build_mongo_filter(request, ('chamber', 'bill_id',
+                                                    'bill_id__in'))
 
         # process extra attributes
         query = request.GET.get('q')
+        abbr = request.GET.get(settings.LEVEL_FIELD)
+        if abbr:
+            abbr = abbr.lower()
         search_window = request.GET.get('search_window', 'all')
         since = request.GET.get('updated_since', None)
+        last_action_since = request.GET.get('last_action_since', None)
         sponsor_id = request.GET.get('sponsor_id')
+        subjects = request.GET.getlist('subject')
+        type_ = request.GET.get('type')
+        status = request.GET.getlist('status')
+
+        # sorting
+        sort = request.GET.get('sort', 'last')
+        if sort == 'last_action':
+            sort = 'last'
 
         try:
             query = Bill.search(query,
+                                abbr=abbr,
                                 search_window=search_window,
-                                updated_since=since, sponsor_id=sponsor_id,
-                                bill_fields=bill_fields,
+                                updated_since=since,
+                                last_action_since=last_action_since,
+                                sponsor_id=sponsor_id,
+                                subjects=subjects, type_=type_, status=status,
+                                sort=sort, bill_fields=bill_fields,
                                 **base_fields)
         except ValueError as e:
             resp = rc.BAD_REQUEST
@@ -205,28 +229,22 @@ class BillSearchHandler(BillyHandler):
         if page:
             page = int(page)
             per_page = int(per_page)
-            query = query.limit(per_page).skip(per_page * (page - 1))
+            start = per_page * (page - 1)
+            end = start + per_page
+            bills = query[start:end]
         else:
             # limit response size
-            if query.count() > 10000:
+            if len(query) > 10000:
                 resp = rc.BAD_REQUEST
                 resp.write(': request too large, try narrowing your search by '
                            'adding more filters.')
                 return resp
+            bills = query[:]
 
-        # sorting
-        sort = request.GET.get('sort')
-        if sort == 'updated_at':
-            query = query.sort([('updated_at', -1)])
-        elif sort == 'created_at':
-            query = query.sort([('created_at', -1)])
-        elif sort == 'last_action':
-            query = query.sort([('action_dates.last', -1)])
-
+        bills = list(bills)
         # attach votes if necessary
-        bills = list(query)
         bill_ids = [bill['_id'] for bill in bills]
-        vote_fields = _get_vote_fields(bill_fields)
+        vote_fields = _get_vote_fields(bill_fields) or []
         if 'votes' in bill_fields or vote_fields:
             # add bill_id to vote_fields for relating back
             votes = list(db.votes.find({'bill_id': {'$in': bill_ids}},
@@ -350,8 +368,7 @@ class SubjectListHandler(BillyHandler):
         if session:
             spec['session'] = session
         if chamber:
-            chamber = chamber.lower()
-            spec['chamber'] = _chamber_aliases.get(chamber, chamber)
+            spec['chamber'] = chamber.lower()
         result = {}
         for subject in settings.BILLY_SUBJECTS:
             count = db.bills.find(dict(spec, subjects=subject)).count()
@@ -370,40 +387,51 @@ class LegislatorGeoHandler(BillyHandler):
             resp.write(': Need lat and long parameters')
             return resp
 
-        url = ("%sboundary/?shape_type=none&contains=%s,%s&sets=sldl,sldu"
-               "&limit=0" % (self.base_url, latitude, longitude))
+        url = "%sboundaries/?contains=%s,%s&sets=%s&limit=0" % (
+            self.base_url, latitude, longitude, settings.BOUNDARY_SERVICE_SETS
+        )
 
         resp = json.load(urllib2.urlopen(url))
 
         filters = []
         boundary_mapping = {}
+        jurisdiction = None
 
         for dist in resp['objects']:
-            abbr = dist['name'][0:2].lower()
-            chamber = {'/1.0/boundary-set/sldu/': 'upper',
-                       '/1.0/boundary-set/sldl/': 'lower'}[dist['set']]
-            census_name = dist['slug']
-
             # look up district slug
-            districts = db.districts.find({'chamber': chamber,
-                                           'boundary_id': census_name})
+            boundary_id = dist['url'].replace('/boundaries/', '').strip('/')
+            districts = db.districts.find({'boundary_id': boundary_id})
             count = districts.count()
-            if count:
-                filters.append({settings.LEVEL_FIELD: abbr,
-                                'district': districts[0]['name'],
-                                'chamber': chamber})
-                boundary_mapping[(abbr, districts[0]['name'],
-                                  chamber)] = census_name
+            if count == 1:
+                filters.append({'district': districts[0]['name'],
+                                'chamber': districts[0]['chamber'],
+                                settings.LEVEL_FIELD: districts[0]['abbr'],
+                               })
+                boundary_mapping[(districts[0]['abbr'],
+                                  districts[0]['name'],
+                                  districts[0]['chamber'])] = boundary_id
+                jurisdiction = districts[0]['abbr']
+            elif count != 0:
+                raise ValueError('multiple districts with boundary_id: %s' %
+                                 boundary_id)
 
         if not filters:
             return []
 
-        legislators = list(db.legislators.find({'$or': filters},
-                                               _build_field_list(request)))
+        if jurisdiction:
+            # append at-large legislators from this jurisdiction
+            filters.append({'district': 'At-Large',
+                            settings.LEVEL_FIELD: jurisdiction})
+
+        fields = _build_field_list(request)
+        if fields is not None:
+            fields['state'] = fields['district'] = fields['chamber'] = 1
+        legislators = list(db.legislators.find({'$or': filters}, fields))
         for leg in legislators:
-            leg['boundary_id'] = boundary_mapping[(leg[settings.LEVEL_FIELD],
-                                                   leg['district'],
-                                                   leg['chamber'])]
+            if leg['district'] != 'At-Large':
+                leg['boundary_id'] = boundary_mapping[(
+                    leg[settings.LEVEL_FIELD], leg['district'], leg['chamber']
+                )]
         return legislators
 
 
@@ -440,21 +468,19 @@ class BoundaryHandler(BillyHandler):
     base_url = settings.BOUNDARY_SERVICE_URL
 
     def read(self, request, boundary_id):
-        url = "%sboundary/%s/?shape_type=simple" % (self.base_url, boundary_id)
+        url = "%sboundaries/%s/simple_shape" % (self.base_url, boundary_id)
         try:
             data = json.load(urllib2.urlopen(url))
-        except urllib2.HTTPError, e:
-            if 400 <= e.code < 500:
+        except urllib2.HTTPError as e:
+            if e.code >= 400:
                 resp = rc.NOT_FOUND
                 return resp
             else:
                 raise e
 
-        centroid = data['centroid']['coordinates']
-
         all_lon = []
         all_lat = []
-        for shape in data['simple_shape']['coordinates']:
+        for shape in data['coordinates']:
             for coord_set in shape:
                 all_lon.extend(c[0] for c in coord_set)
                 all_lat.extend(c[1] for c in coord_set)
@@ -467,14 +493,26 @@ class BoundaryHandler(BillyHandler):
         lon_delta = abs(max_lon - min_lon)
         lat_delta = abs(max_lat - min_lat)
 
-        region = {'center_lon': centroid[0], 'center_lat': centroid[1],
+        region = {'center_lon': (max_lon + min_lon) / 2,
+                  'center_lat': (max_lat + min_lat) / 2,
                   'lon_delta': lon_delta, 'lat_delta': lat_delta,
                  }
         bbox = [[min_lat, min_lon], [max_lat, max_lon]]
 
         district = db.districts.find_one({'boundary_id': boundary_id})
-        district['shape'] = data['simple_shape']['coordinates']
+        if not district:
+            resp = rc.NOT_FOUND
+            return resp
+        district['shape'] = data['coordinates']
         district['region'] = region
         district['bbox'] = bbox
 
         return district
+
+
+class NewsHandler(BillyHandler):
+
+    def read(self, request, id):
+        fields = ['entity_ids', 'entity_strings', 'link']
+        entries = feeds_db.entries.find({'entity_ids': id}, fields=fields)
+        return dict(count=entries.count(), entries=list(entries))
