@@ -7,6 +7,7 @@ from django.utils.html import strip_tags
 from django.template.defaultfilters import truncatewords
 
 from billy.models import db
+from billy.utils import get_domain
 
 
 def take(n, iterable):
@@ -52,8 +53,8 @@ class VotesListFeed(GenericListFeed):
     sort = [('date', pymongo.DESCENDING)]
 
     def title(self, obj):
-        s = u"OpenStates.org: Votes by {0}."
-        return s.format(obj.display_name())
+        s = u"{0}: Votes by {1}."
+        return s.format(get_domain(), obj.display_name())
 
     description = title
 
@@ -75,8 +76,8 @@ class NewsListFeed(GenericListFeed):
     query_attribute = 'feed_entries'
 
     def title(self, obj):
-        s = u"OpenStates.org: News stories mentioning {0}."
-        return s.format(obj.display_name())
+        s = u"{0}: News stories mentioning {1}."
+        return s.format(get_domain(), obj.display_name())
 
     description = title
 
@@ -95,13 +96,13 @@ class NewsListFeed(GenericListFeed):
         return '%s (%s)' % (item['title'], published)
 
 
-class StateEventsFeed(GenericListFeed):
+class EventsFeed(GenericListFeed):
     collection_name = 'metadata'
     query_attribute = 'events'
 
     def title(self, obj):
-        s = u"OpenStates.org: {0} legislative events."
-        return s.format(obj.display_name())
+        s = u"{0}: {1} legislative events."
+        return s.format(get_domain(), obj.display_name())
 
     description = title
 
