@@ -1,7 +1,8 @@
 from django.conf import settings
 from django.conf.urls.defaults import patterns, include, url
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     (r'^api/', include('billy.web.api.urls')),
     (r'^admin/', include('billy.web.admin.urls')),
     (r'^public/', include('billy.web.public.urls')),
